// post.controller.ts
import { Controller, Get, Post, Body, Patch, Param, Delete } from '@nestjs/common';
import { CreatePostDto } from './dto/create-post.dto';
import { UpdatePostDto } from './dto/update-post.dto';
import { RemovePostDto } from './dto/remove-post.dto';
import { PostService } from './post.service';

@Controller('post')
export class PostController {
  constructor(private readonly postService: PostService) {}

  @Post()
  create(@Body() createPostDto: CreatePostDto) {
    return this.postService.create(createPostDto);
  }

  @Get()
  findAll() {
    return this.postService.findAll();
  }

  // GET http://localhost:3000/post/1
  @Get(':id') // 인자가 ':'로 시작하는건 파라미터로 쓰인다는 뜻
  findOne(@Param('id') id: string) {
    return this.postService.findOne(+id);
  }

  // PATCH http://localhost:3000/post/1
  @Patch(':id')
  // @Param(파람) : 'id'를 id의 값(문자열 타입)으로 받는다는 뜻
  update(@Param('id') id: string, @Body() updatePostDto: UpdatePostDto) {
    return this.postService.update(+id, updatePostDto); // service에서는 id가 숫자타입
  }

  // DELETE http://localhost:3000/post/1
  @Delete(':id')
  remove(@Param('id') id: string, @Body() deletePostDto: RemovePostDto) {
    return this.postService.remove(+id, deletePostDto);
  }
}
